
From: "Randy.Dunlap" <rddunlap@osdl.org>

Convert IPMI driver struct usage to C99 initializers.

Signed-off-by: Randy Dunlap <rddunlap@osdl.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/char/ipmi/ipmi_msghandler.c |    6 +++---
 25-akpm/drivers/char/ipmi/ipmi_poweroff.c   |   12 +++++++++---
 25-akpm/drivers/char/ipmi/ipmi_watchdog.c   |   24 ++++++++++++------------
 3 files changed, 24 insertions(+), 18 deletions(-)

diff -puN drivers/char/ipmi/ipmi_msghandler.c~ipmi-use-c99-struct-inits drivers/char/ipmi/ipmi_msghandler.c
--- 25/drivers/char/ipmi/ipmi_msghandler.c~ipmi-use-c99-struct-inits	2004-12-03 20:57:25.926697344 -0800
+++ 25-akpm/drivers/char/ipmi/ipmi_msghandler.c	2004-12-03 20:57:25.934696128 -0800
@@ -3038,9 +3038,9 @@ static int panic_event(struct notifier_b
 }
 
 static struct notifier_block panic_block = {
-	panic_event,
-	NULL,
-	200   /* priority: INT_MAX >= x >= 0 */
+	.notifier_call	= panic_event,
+	.next		= NULL,
+	.priority	= 200	/* priority: INT_MAX >= x >= 0 */
 };
 
 static int ipmi_init_msghandler(void)
diff -puN drivers/char/ipmi/ipmi_poweroff.c~ipmi-use-c99-struct-inits drivers/char/ipmi/ipmi_poweroff.c
--- 25/drivers/char/ipmi/ipmi_poweroff.c~ipmi-use-c99-struct-inits	2004-12-03 20:57:25.927697192 -0800
+++ 25-akpm/drivers/char/ipmi/ipmi_poweroff.c	2004-12-03 20:57:25.934696128 -0800
@@ -381,11 +381,17 @@ struct poweroff_function {
 };
 
 static struct poweroff_function poweroff_functions[] = {
-	{ "ATCA",    ipmi_atca_detect, ipmi_poweroff_atca },
-	{ "CPI1",    ipmi_cpi1_detect, ipmi_poweroff_cpi1 },
+	{ .platform_type	= "ATCA",
+	  .detect		= ipmi_atca_detect,
+	  .poweroff_func	= ipmi_poweroff_atca },
+	{ .platform_type	= "CPI1",
+	  .detect		= ipmi_cpi1_detect,
+	  .poweroff_func	= ipmi_poweroff_cpi1 },
 	/* Chassis should generally be last, other things should override
 	   it. */
-	{ "chassis", ipmi_chassis_detect, ipmi_poweroff_chassis },
+	{ .platform_type	= "chassis",
+	  .detect		= ipmi_chassis_detect,
+	  .poweroff_func	= ipmi_poweroff_chassis },
 };
 #define NUM_PO_FUNCS (sizeof(poweroff_functions) \
 		      / sizeof(struct poweroff_function))
diff -puN drivers/char/ipmi/ipmi_watchdog.c~ipmi-use-c99-struct-inits drivers/char/ipmi/ipmi_watchdog.c
--- 25/drivers/char/ipmi/ipmi_watchdog.c~ipmi-use-c99-struct-inits	2004-12-03 20:57:25.929696888 -0800
+++ 25-akpm/drivers/char/ipmi/ipmi_watchdog.c	2004-12-03 20:57:25.935695976 -0800
@@ -504,9 +504,9 @@ static void panic_halt_ipmi_heartbeat(vo
 
 static struct watchdog_info ident=
 {
-	0, /* WDIOF_SETTIMEOUT, */
-	1,
-	"IPMI"
+	.options	= 0,	/* WDIOF_SETTIMEOUT, */
+	.firmware_version = 1,
+	.identity	= "IPMI"
 };
 
 static int ipmi_ioctl(struct inode *inode, struct file *file,
@@ -734,9 +734,9 @@ static struct file_operations ipmi_wdog_
 };
 
 static struct miscdevice ipmi_wdog_miscdev = {
-	WATCHDOG_MINOR,
-	"watchdog",
-	&ipmi_wdog_fops
+	.minor		= WATCHDOG_MINOR,
+	.name		= "watchdog",
+	.fops		= &ipmi_wdog_fops
 };
 
 static DECLARE_RWSEM(register_sem);
@@ -871,9 +871,9 @@ static int wdog_reboot_handler(struct no
 }
 
 static struct notifier_block wdog_reboot_notifier = {
-	wdog_reboot_handler,
-	NULL,
-	0
+	.notifier_call	= wdog_reboot_handler,
+	.next		= NULL,
+	.priority	= 0
 };
 
 static int wdog_panic_handler(struct notifier_block *this,
@@ -899,9 +899,9 @@ static int wdog_panic_handler(struct not
 }
 
 static struct notifier_block wdog_panic_notifier = {
-	wdog_panic_handler,
-	NULL,
-	150   /* priority: INT_MAX >= x >= 0 */
+	.notifier_call	= wdog_panic_handler,
+	.next		= NULL,
+	.priority	= 150	/* priority: INT_MAX >= x >= 0 */
 };
 
 
_
